#!/usr/bin/env python
"""Django's command-line utility for administrative tasks."""
import os
from pathlib import Path
import requests
import subprocess
import sys
import zipfile


def install_validator_nu():
    jar = Path('vnu.jar')
    if not jar.exists():
        path = Path('vnu.jar.zip')
        if not path.exists():
            resp = requests.get(
                'https://api.github.com/repos/validator/validator/releases/latest'
            )
            resp.raise_for_status()
            latest = resp.json()
            assets = latest['assets']
            desired_assets = list(filter(lambda a: a['name'].startswith(
                'vnu.jar') and a['name'].endswith('.zip'), assets))
            desired_asset = desired_assets[0]
            desired_asset_url = desired_asset['browser_download_url']
            asset = requests.get(desired_asset_url)
            asset.raise_for_status()
            path.write_bytes(asset.content)
        z = zipfile.ZipFile(path)
        jar.write_bytes(z.read('dist/vnu.jar'))


def install_accessibility_checker():
    if not (Path('.')/'node_modules'/'accessibility-checker'/'bin'/'achecker.js').exists():
        subprocess.run(
            [
                'npm',
                'i',
                'accessibility-checker'
            ],
            check=True
        )


def install_puppeteer():
    if not (Path('.')/'node_modules'/'puppeteer').exists():
        subprocess.run(
            [
                'npm',
                'i',
                'puppeteer'
            ],
            check=True
        )


def main():
    os.chdir(Path(__file__).parent)
    install_accessibility_checker()
    install_puppeteer()
    install_validator_nu()
    if '_JAVA_OPTIONS' in os.environ:
        del os.environ['_JAVA_OPTIONS']
    """Run administrative tasks."""
    os.environ.setdefault('DJANGO_SETTINGS_MODULE', 'webproj.settings')
    try:
        from django.core.management import execute_from_command_line
    except ImportError as exc:
        raise ImportError(
            "Couldn't import Django. Are you sure it's installed and "
            "available on your PYTHONPATH environment variable? Did you "
            "forget to activate a virtual environment?"
        ) from exc
    execute_from_command_line(sys.argv)


if __name__ == '__main__':
    main()
